==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/ServicePortFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ServicePortFluent<A extends io.fabric8.kubernetes.api.model.ServicePortFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAppProtocol();
  public A withAppProtocol(java.lang.String appProtocol);
  public java.lang.Boolean hasAppProtocol();
  
  /**
   * Method is deprecated. use withAppProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewAppProtocol(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Integer getNodePort();
  public A withNodePort(java.lang.Integer nodePort);
  public java.lang.Boolean hasNodePort();
  public java.lang.Integer getPort();
  public A withPort(java.lang.Integer port);
  public java.lang.Boolean hasPort();
  public java.lang.String getProtocol();
  public A withProtocol(java.lang.String protocol);
  public java.lang.Boolean hasProtocol();
  
  /**
   * Method is deprecated. use withProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewProtocol(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildTargetPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getTargetPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildTargetPort();
  public A withTargetPort(io.fabric8.kubernetes.api.model.IntOrString targetPort);
  public java.lang.Boolean hasTargetPort();
  public A withNewTargetPort(java.lang.Integer intVal);
  public A withNewTargetPort(java.lang.String strVal);
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> withNewTargetPort();
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> withNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> editTargetPort();
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> editOrNewTargetPort();
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> editOrNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public interface TargetPortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<N>>{
    public N and();
    public N endTargetPort();
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/ServicePortFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ServicePortFluent<A extends io.fabric8.kubernetes.api.model.ServicePortFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAppProtocol();
  public A withAppProtocol(java.lang.String appProtocol);
  public java.lang.Boolean hasAppProtocol();
  
  /**
   * Method is deprecated. use withAppProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewAppProtocol(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Integer getNodePort();
  public A withNodePort(java.lang.Integer nodePort);
  public java.lang.Boolean hasNodePort();
  public java.lang.Integer getPort();
  public A withPort(java.lang.Integer port);
  public java.lang.Boolean hasPort();
  public java.lang.String getProtocol();
  public A withProtocol(java.lang.String protocol);
  public java.lang.Boolean hasProtocol();
  
  /**
   * Method is deprecated. use withProtocol instead.
   */
  @java.lang.Deprecated
  public A withNewProtocol(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildTargetPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getTargetPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildTargetPort();
  public A withTargetPort(io.fabric8.kubernetes.api.model.IntOrString targetPort);
  public java.lang.Boolean hasTargetPort();
  public A withNewTargetPort(java.lang.Integer intVal);
  public A withNewTargetPort(java.lang.String strVal);
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> withNewTargetPort();
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> withNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> editTargetPort();
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> editOrNewTargetPort();
  public io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<A> editOrNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface TargetPortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.kubernetes.api.model.ServicePortFluent.TargetPortNested<N>>{
    public N and();
    public N endTargetPort();
    
  }
  
}
